@@ -83,30 +83,36 @@ watch_dir = function(dir = '.', pattern = NULL, all_files = FALSE, handler = NUL
 #'   \code{\link{commandArgs}()}); N.B. the RStudio viewer is used as the web
 #'   browser if available
 #' @param daemon whether to launch a daemonized server (the server does not
-#'   block the current R session) or a blocking server; by default, it is
-#'   \code{TRUE} if a command line argument \code{-d} was passed to R (through
-#'   \command{Rscript}); normally it should be \code{FALSE} by default
+#'   block the current R session) or a blocking server; by default, it is the
+#'   global option \code{getOption('servr.daemon')} (e.g., you can set
+#'   \code{options(servr.daemon = TRUE)}); if this option was not set,
+#'   \code{daemon = TRUE} if a command line argument \code{-d} was passed to R
+#'   (through \command{Rscript}); normally it should be \code{FALSE} by default
 #' @param interval the time interval used to check if an HTML page needs to be
 #'   rebuilt (by default, it is checked every second); at the moment, the
 #'   smallest possible \code{interval} is set to be 1, and this may change in
 #'   the future
 #' @param baseurl the base URL (the full URL will be
 #'   \code{http://host:port/baseurl})
+#' @param initpath the initial path in the URL (e.g. you can open a specific
+#'   HTML file initially)
 #' @inheritParams httpuv::startServer
 #' @return A list of configuration information of the form \code{list(host,
 #'   port, start_server = function(app) {}, ...)}.
 server_config = function(
-  dir, host = '127.0.0.1', port, browser, daemon, interval = 1, baseurl = ''
+  dir, host = '127.0.0.1', port, browser, daemon, interval = 1, baseurl = '',
+  initpath = ''
 ) {
   cargs = commandArgs(TRUE)
   if (missing(browser)) browser = interactive() || '-b' %in% cargs || is_rstudio()
   if (missing(port))
     port = if (length(port <- grep('^-p[0-9]{4,}$', cargs, value = TRUE)) == 1)
       as.integer(sub('^-p', '', port)) else random_port(4321L)
-  if (missing(daemon)) daemon = '-d' %in% cargs
+  if (missing(daemon)) daemon = getOption('servr.daemon', '-d' %in% cargs)
   damn_library('methods')
   url = sprintf('http://%s:%d', host, port)
   if (baseurl != '') url = paste(url, baseurl, sep = '')
+  url = paste0(url, if (initpath != '' && !grepl('^/', initpath)) '/', initpath)
   list(
     host = host,
     port = port,
